==> concierge-1.1.0-alpha2-sources.jar: com/flybits/concierge/activities/NotificationsActivity.kt <==
package com.flybits.concierge.activities

import android.content.Intent
import android.net.Uri
import android.os.Bundle
import android.support.v4.app.Fragment
import android.support.v7.app.AppCompatActivity
import android.view.MenuItem
import com.afollestad.materialdialogs.MaterialDialog
import com.flybits.android.push.models.Push
import com.flybits.commons.library.logging.Logger
import com.flybits.concierge.*
import com.flybits.concierge.fragments.NotificationsFragment
import com.flybits.concierge.models.BaseTemplate

class NotificationsActivity: AppCompatActivity(), FlybitsNavigator, FlybitsViewProviderGetter {

    override fun openFragment(fragment: Fragment, addToBackStack: Boolean) {
        val transaction = supportFragmentManager.beginTransaction()
        if (addToBackStack){
            transaction.addToBackStack(null)
        }
        transaction.replace(R.id.flybits_con_activity_notifications_fragment_holder, fragment)
                .commit()
    }

    override fun openUrl(url: String) {
        val intent = Intent(Intent.ACTION_VIEW, Uri.parse(url))
        //verify that you're able to open url, if URL is malformed then exception is thrown
        if (intent.resolveActivity(packageManager) != null){
            startActivity(intent)
        } else {
            Logger.e("NotificationsActivity: Unable to show url $url, make sure it has http:// prefixed.")
        }
    }

    override fun openDialog(content: String, title: String) {
        MaterialDialog.Builder(this)
                .title(title)
                .content(content)
                .positiveText(android.R.string.ok)
                .show()
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        return if (item.itemId == android.R.id.home) {
            onBackPressed()
            true
        } else {
            super.onOptionsItemSelected(item)
        }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.flybits_con_activity_notifications)

        val notificationsFragment = if (intent.hasExtra(ConciergeConstants.PUSH_EXTRA)) {
            val push = intent.getParcelableExtra<Push>(ConciergeConstants.PUSH_EXTRA)
            intent.removeExtra(ConciergeConstants.PUSH_EXTRA)
            NotificationsFragment.newInstance(push)
        } else {
            NotificationsFragment.newInstance()
        }
        openFragment(notificationsFragment, false)

        val actionBar = supportActionBar
        actionBar?.setDisplayHomeAsUpEnabled(true)
        actionBar?.title = getString(R.string.flybits_con_notifications)
    }

    override fun getFlybitsViewProviders(): Collection<FlybitsViewProvider<BaseTemplate>>? {
        applicationContext?.let {
            return FlybitsConcierge.with(it).flybitsViewProviders
        } ?: return emptyList()
    }

    override fun getFlybitsViewProvider(contentType: String): FlybitsViewProvider<BaseTemplate>? {
        applicationContext?.let { nonNullContext ->
            return FlybitsConcierge.with(nonNullContext).flybitsViewProviders
                    .find { it.getContentType() == contentType } as FlybitsViewProvider<BaseTemplate>?
        } ?: return null
    }

}

==> concierge-3.0.0-alpha2-sources.jar: com/flybits/concierge/activities/NotificationsActivity.kt <==
package com.flybits.concierge.activities

import android.content.Intent
import android.net.Uri
import android.os.Bundle
import com.google.android.material.snackbar.Snackbar
import androidx.fragment.app.Fragment
import androidx.appcompat.app.AppCompatActivity
import android.view.MenuItem
import com.afollestad.materialdialogs.MaterialDialog
import com.flybits.android.push.models.newPush.Push
import com.flybits.commons.library.logging.Logger
import com.flybits.concierge.ConciergeConstants
import com.flybits.concierge.FlybitsNavigator
import com.flybits.concierge.R
import com.flybits.concierge.fragments.NotificationsFragment

class NotificationsActivity: AppCompatActivity(), FlybitsNavigator {

    override fun openFragment(fragment: Fragment, addToBackStack: Boolean) {
        val transaction = supportFragmentManager.beginTransaction()
        if (addToBackStack){
            transaction.addToBackStack(null)
        }
        transaction.replace(R.id.flybits_con_activity_notifications_fragment_holder, fragment)
                .commit()
    }

    override fun openActivity(activity: Class<*>, extras: Bundle) {
        val intent = Intent(this, activity)
        intent.putExtras(extras)
        startActivity(intent)
    }

    override fun openUrl(url: String): Boolean {
        val intent = Intent(Intent.ACTION_VIEW, Uri.parse(url))
        //verify that you're able to open url, if URL is malformed then exception is thrown
        return if (intent.resolveActivity(packageManager) != null){
            startActivity(intent)
            true
        } else {
            Logger.e("NotificationsActivity: Unable to show url $url, make sure it has http:// prefixed.")
            false
        }
    }

    override fun openDialog(content: String, title: String) {
        MaterialDialog.Builder(this)
                .title(title)
                .content(content)
                .positiveText(android.R.string.ok)
                .show()
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        return if (item.itemId == android.R.id.home) {
            onBackPressed()
            true
        } else {
            super.onOptionsItemSelected(item)
        }
    }

    override fun openSnackbar(content: String, length: Int) {
        Snackbar.make(findViewById(android.R.id.content), content, Snackbar.LENGTH_SHORT).show()
    }

    override fun dismiss() {
        finish()
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.flybits_con_activity_notifications)

        val notificationsFragment = if (intent.hasExtra(ConciergeConstants.PUSH_EXTRA)) {
            val push = intent.getParcelableExtra<Push>(ConciergeConstants.PUSH_EXTRA)
            intent.removeExtra(ConciergeConstants.PUSH_EXTRA)
            NotificationsFragment.newInstance(push)
        } else {
            NotificationsFragment.newInstance()
        }
        openFragment(notificationsFragment, false)

        val actionBar = supportActionBar
        actionBar?.setDisplayHomeAsUpEnabled(true)
        actionBar?.title = getString(R.string.flybits_con_notifications)
    }
}
